@@ -1,14 +1,9 @@
+// SPDX-License-Identifier: LGPL-2.1-or-later
 //
-// This file is part of the Marble Virtual Globe.
-//
-// This program is free software licensed under the GNU LGPL. You can
-// find a copy of this license in LICENSE.txt in the top directory of
-// the source code.
-//
-// Copyright 2006-2007 Torsten Rahn <tackat@kde.org>
-// Copyright 2007-2008 Inge Wallin  <ingwa@kde.org>
-// Copyright 2008      Patrick Spendrin <ps_ml@gmx.de>
-// Copyright 2015      Alejandro Garcia Montoro <alejandro.garciamontoro@gmail.com>
+// SPDX-FileCopyrightText: 2006-2007 Torsten Rahn <tackat@kde.org>
+// SPDX-FileCopyrightText: 2007-2008 Inge Wallin <ingwa@kde.org>
+// SPDX-FileCopyrightText: 2008 Patrick Spendrin <ps_ml@gmx.de>
+// SPDX-FileCopyrightText: 2015 Alejandro Garcia Montoro <alejandro.garciamontoro@gmail.com>
 //
 
 
@@ -261,6 +256,8 @@ class GEODATA_EXPORT GeoDataCoordinates
      */
     GeoDataCoordinates rotateAround( const GeoDataCoordinates &axis, qreal angle, Unit unit = Radian ) const;
 
+    GeoDataCoordinates rotateAround(const Quaternion &rotAxis) const;
+
     /**
      * @brief Returns the bearing (true bearing, the angle between the line defined
      * by this point and the other and the prime meridian)
@@ -293,6 +290,14 @@ class GEODATA_EXPORT GeoDataCoordinates
      */
     GeoDataCoordinates interpolate( const GeoDataCoordinates &target, double t ) const;
 
+    /**
+     * @brief nlerp (normalized linear interpolation) between this coordinates and the given target coordinates
+     * @param target Destination coordinates
+     * @param t Fraction 0..1 to weight between this and target
+     * @return Interpolated coordinate between this (t<=0.0) and target (t>=1.0)
+     */
+    GeoDataCoordinates nlerp(const GeoDataCoordinates &target, double t) const;
+
     /**
      * @brief squad (spherical and quadrangle) interpolation between b and c
      * @param before First base point
@@ -311,7 +316,7 @@ class GEODATA_EXPORT GeoDataCoordinates
 
     /**
      * @brief This method calculates the shortest distance between two points on a sphere.
-     * @brief See: http://en.wikipedia.org/wiki/Great-circle_distance
+     * @brief See: https://en.wikipedia.org/wiki/Great-circle_distance
      */
     qreal sphericalDistanceTo(const GeoDataCoordinates &other) const;
 
